cmoncrawl.processor.pipeline.streamer.StreamerFileJSON.\_\_init\_\_
===================================================================

.. currentmodule:: cmoncrawl.processor.pipeline.streamer

.. automethod:: StreamerFileJSON.__init__